;;; async-pkg.el --- Generated package description from async.el
(define-package "async" "1.9.3"
  "Asynchronous processing in Emacs"
  'nil
  :url "https://github.com/jwiegley/emacs-async"
  :keywords '("async"))

;; Local Variables:
;; no-byte-compile: t
;; End:
